==> infima_client-0.59.0-py3-none-any.whl: infima_client/api/pool_service/pool_service_get_characteristics.py <==
from typing import Any, Dict, List, Optional, Union

import httpx

from ...client import Client
from ...models.pool_characteristics import PoolCharacteristics
from ...models.pool_characteristics_error import PoolCharacteristicsError
from ...models.pool_characteristics_not_found import PoolCharacteristicsNotFound
from ...models.pool_characteristics_unauthorized import PoolCharacteristicsUnauthorized
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/pools/characteristics".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_cusips: Union[Unset, List[Any]] = UNSET
    if not isinstance(cusips, Unset):
        json_cusips = cusips

    params: Dict[str, Any] = {
        "CUSIPS": json_cusips,
        "date.year": dateyear,
        "date.month": datemonth,
        "date.day": dateday,
    }
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    if response.status_code == 200:
        response_200 = PoolCharacteristics.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = PoolCharacteristicsUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PoolCharacteristicsNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PoolCharacteristicsError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    """


    Args:
        cusips: None
        dateyear: Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year
        datemonth: Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.
        dateday: Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant.Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day.

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Response[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        cusips=cusips,
        dateyear=dateyear,
        datemonth=datemonth,
        dateday=dateday,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    cusips: Union[Unset, List[str]] = UNSET,
    dateyear: Union[Unset, int] = UNSET,
    datemonth: Union[Unset, int] = UNSET,
    dateday: Union[Unset, int] = UNSET,
) -> Optional[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            cusips=cusips,
            dateyear=dateyear,
            datemonth=datemonth,
            dateday=dateday,
        )
    ).parsed

==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/pool_service/pool_service_get_characteristics.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.get_pool_charasteristics_request import GetPoolCharasteristicsRequest
from ...models.pool_characteristics import PoolCharacteristics
from ...models.pool_characteristics_error import PoolCharacteristicsError
from ...models.pool_characteristics_not_found import PoolCharacteristicsNotFound
from ...models.pool_characteristics_unauthorized import PoolCharacteristicsUnauthorized
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: GetPoolCharasteristicsRequest,
) -> Dict[str, Any]:
    url = "{}/api/v1/pools/characteristics".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    if response.status_code == 200:
        response_200 = PoolCharacteristics.from_dict(response.json())

        return response_200
    if response.status_code == 401:
        response_401 = PoolCharacteristicsUnauthorized.from_dict(response.json())

        return response_401
    if response.status_code == 404:
        response_404 = PoolCharacteristicsNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PoolCharacteristicsError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: GetPoolCharasteristicsRequest,
) -> Response[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: GetPoolCharasteristicsRequest,
) -> Optional[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    """


    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: GetPoolCharasteristicsRequest,
) -> Response[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: GetPoolCharasteristicsRequest,
) -> Optional[
    Union[
        PoolCharacteristics,
        PoolCharacteristicsUnauthorized,
        PoolCharacteristicsNotFound,
        PoolCharacteristicsError,
    ]
]:
    """  """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
